@@ -5,6 +5,7 @@ import webbrowser
 import sys
 
 
+
 # Set and get important environmental variables
 
 def set_api_key(api_key=None):
@@ -31,9 +32,14 @@ def key_signup():
                      'No': False, 'N': False}
     answer = input('Please run set_api_key first. Otherwise,do you want to sign up for an api key?! Yes or No?')
 
-    if valid_choices[answer]:
-        sys.stdout.write("\033[0;31m")
-        sys.stdout.write("Now taking you to the api key sign up page.")
-        webbrowser.open("https://fdc.nal.usda.gov/api-key-signup.html", new=2)
-    else:
-        raise ValueError("You provided no api key. Please provide one and try again")
+    try:
+        if valid_choices[answer]:
+            sys.stdout.write("\033[0;31m")
+            sys.stdout.write("Now taking you to the api key sign up page...")
+            webbrowser.open("https://fdc.nal.usda.gov/api-key-signup.html", new=2)
+        else:
+            raise ValueError("You provided no api key. Please provide one and try again")
+    except KeyError:
+        raise
+
+
